@@ -2192,7 +2192,7 @@ class ServiceManagerClient(metaclass=ServiceManagerClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "ServiceManagerClient":
         return self
 
     def __exit__(self, type, value, traceback):
